/* ide-terminal-palettes-inline.h
 *
 * Copyright 2023 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include "ide-terminal-palette.h"

G_BEGIN_DECLS

typedef struct _IdeTerminalPaletteData
{
  const char             *id;
  const char             *name;
  IdeTerminalPaletteFace  faces[2];
} IdeTerminalPaletteData;

static const IdeTerminalPaletteData ide_terminal_palettes_inline[] = {
  {
    .id = "gnome",
    .name = N_("GNOME"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x1e/255., 0x1e/255., 0x1e/255., 1.},
        .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x1e/255., 0x1e/255., 0x1e/255., 1.},
          (GdkRGBA) { 0xc0/255., 0x1c/255., 0x28/255., 1.},
          (GdkRGBA) { 0x26/255., 0xa2/255., 0x69/255., 1.},
          (GdkRGBA) { 0xa2/255., 0x73/255., 0x4c/255., 1.},
          (GdkRGBA) { 0x12/255., 0x48/255., 0x8b/255., 1.},
          (GdkRGBA) { 0xa3/255., 0x47/255., 0xba/255., 1.},
          (GdkRGBA) { 0x2a/255., 0xa1/255., 0xb3/255., 1.},
          (GdkRGBA) { 0xd0/255., 0xcf/255., 0xcc/255., 1.},
          (GdkRGBA) { 0x5e/255., 0x5c/255., 0x64/255., 1.},
          (GdkRGBA) { 0xf6/255., 0x61/255., 0x51/255., 1.},
          (GdkRGBA) { 0x33/255., 0xd1/255., 0x7a/255., 1.},
          (GdkRGBA) { 0xe9/255., 0xad/255., 0x0c/255., 1.},
          (GdkRGBA) { 0x2a/255., 0x7b/255., 0xde/255., 1.},
          (GdkRGBA) { 0xc0/255., 0x61/255., 0xcb/255., 1.},
          (GdkRGBA) { 0x33/255., 0xc7/255., 0xde/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .background = (GdkRGBA) { 0x1e/255., 0x1e/255., 0x1e/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x1e/255., 0x1e/255., 0x1e/255., 1.},
          (GdkRGBA) { 0xc0/255., 0x1c/255., 0x28/255., 1.},
          (GdkRGBA) { 0x26/255., 0xa2/255., 0x69/255., 1.},
          (GdkRGBA) { 0xa2/255., 0x73/255., 0x4c/255., 1.},
          (GdkRGBA) { 0x12/255., 0x48/255., 0x8b/255., 1.},
          (GdkRGBA) { 0xa3/255., 0x47/255., 0xba/255., 1.},
          (GdkRGBA) { 0x2a/255., 0xa1/255., 0xb3/255., 1.},
          (GdkRGBA) { 0xd0/255., 0xcf/255., 0xcc/255., 1.},
          (GdkRGBA) { 0x5e/255., 0x5c/255., 0x64/255., 1.},
          (GdkRGBA) { 0xf6/255., 0x61/255., 0x51/255., 1.},
          (GdkRGBA) { 0x33/255., 0xd1/255., 0x7a/255., 1.},
          (GdkRGBA) { 0xe9/255., 0xad/255., 0x0c/255., 1.},
          (GdkRGBA) { 0x2a/255., 0x7b/255., 0xde/255., 1.},
          (GdkRGBA) { 0xc0/255., 0x61/255., 0xcb/255., 1.},
          (GdkRGBA) { 0x33/255., 0xc7/255., 0xde/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
    },
  },

  {
    .id = "solarized",
    .name = N_("Solarized"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x00/255., 0x2b/255., 0x36/255., 1.},
        .background = (GdkRGBA) { 0xfd/255., 0xf6/255., 0xe3/255., 1.},
        .cursor = (GdkRGBA) { 0x93/255., 0xa1/255., 0xa1/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x07/255., 0x36/255., 0x42/255., 1.},
          (GdkRGBA) { 0xdc/255., 0x32/255., 0x2f/255., 1.},
          (GdkRGBA) { 0x85/255., 0x99/255., 0x00/255., 1.},
          (GdkRGBA) { 0xb5/255., 0x89/255., 0x00/255., 1.},
          (GdkRGBA) { 0x26/255., 0x8a/255., 0xd2/255., 1.},
          (GdkRGBA) { 0xd3/255., 0x36/255., 0x82/255., 1.},
          (GdkRGBA) { 0x2a/255., 0xa1/255., 0x98/255., 1.},
          (GdkRGBA) { 0xee/255., 0xe8/255., 0xd5/255., 1.},
          (GdkRGBA) { 0x00/255., 0x2b/255., 0x36/255., 1.},
          (GdkRGBA) { 0xcb/255., 0x4b/255., 0x16/255., 1.},
          (GdkRGBA) { 0x65/255., 0x7b/255., 0x83/255., 1.},
          (GdkRGBA) { 0x58/255., 0x6e/255., 0x75/255., 1.},
          (GdkRGBA) { 0x93/255., 0xa1/255., 0xa1/255., 1.},
          (GdkRGBA) { 0x6c/255., 0x71/255., 0xc4/255., 1.},
          (GdkRGBA) { 0x83/255., 0x94/255., 0x96/255., 1.},
          (GdkRGBA) { 0xfd/255., 0xf6/255., 0xe3/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0x83/255., 0x94/255., 0x96/255., 1.},
        .background = (GdkRGBA) { 0x00/255., 0x2b/255., 0x36/255., 1.},
        .cursor = (GdkRGBA) { 0x93/255., 0xa1/255., 0xa1/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x07/255., 0x36/255., 0x42/255., 1.},
          (GdkRGBA) { 0xdc/255., 0x32/255., 0x2f/255., 1.},
          (GdkRGBA) { 0x85/255., 0x99/255., 0x00/255., 1.},
          (GdkRGBA) { 0xb5/255., 0x89/255., 0x00/255., 1.},
          (GdkRGBA) { 0x26/255., 0x8b/255., 0xd2/255., 1.},
          (GdkRGBA) { 0xd3/255., 0x36/255., 0x82/255., 1.},
          (GdkRGBA) { 0x2a/255., 0xa1/255., 0x98/255., 1.},
          (GdkRGBA) { 0xee/255., 0xe8/255., 0xd5/255., 1.},
          (GdkRGBA) { 0x00/255., 0x2b/255., 0x36/255., 1.},
          (GdkRGBA) { 0xcb/255., 0x4b/255., 0x16/255., 1.},
          (GdkRGBA) { 0x58/255., 0x6e/255., 0x75/255., 1.},
          (GdkRGBA) { 0x65/255., 0x7b/255., 0x83/255., 1.},
          (GdkRGBA) { 0x83/255., 0x94/255., 0x96/255., 1.},
          (GdkRGBA) { 0x6c/255., 0x71/255., 0xc4/255., 1.},
          (GdkRGBA) { 0x93/255., 0xa1/255., 0xa1/255., 1.},
          (GdkRGBA) { 0xfd/255., 0xf6/255., 0xe3/255., 1.},
        },
      },
    },
  },

  {
    .id = "tango",
    .name = N_("Tango"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x2e/255., 0x34/255., 0x36/255., 1.},
        .background = (GdkRGBA) { 0xee/255., 0xee/255., 0xec/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x2e/255., 0x34/255., 0x36/255., 1.},
          (GdkRGBA) { 0xcc/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x4e/255., 0x9a/255., 0x06/255., 1.},
          (GdkRGBA) { 0xc4/255., 0xa0/255., 0x00/255., 1.},
          (GdkRGBA) { 0x34/255., 0x65/255., 0xa4/255., 1.},
          (GdkRGBA) { 0x75/255., 0x50/255., 0x7b/255., 1.},
          (GdkRGBA) { 0x06/255., 0x98/255., 0x9a/255., 1.},
          (GdkRGBA) { 0xd3/255., 0xd7/255., 0xcf/255., 1.},
          (GdkRGBA) { 0x55/255., 0x57/255., 0x53/255., 1.},
          (GdkRGBA) { 0xef/255., 0x29/255., 0x29/255., 1.},
          (GdkRGBA) { 0x8a/255., 0xe2/255., 0x34/255., 1.},
          (GdkRGBA) { 0xfc/255., 0xe9/255., 0x4f/255., 1.},
          (GdkRGBA) { 0x72/255., 0x9f/255., 0xcf/255., 1.},
          (GdkRGBA) { 0xad/255., 0x7f/255., 0xa8/255., 1.},
          (GdkRGBA) { 0x34/255., 0xe2/255., 0xe2/255., 1.},
          (GdkRGBA) { 0xee/255., 0xee/255., 0xec/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xd3/255., 0xd7/255., 0xcf/255., 1.},
        .background = (GdkRGBA) { 0x2e/255., 0x34/255., 0x36/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x2e/255., 0x34/255., 0x36/255., 1.},
          (GdkRGBA) { 0xcc/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x4e/255., 0x9a/255., 0x06/255., 1.},
          (GdkRGBA) { 0xc4/255., 0xa0/255., 0x00/255., 1.},
          (GdkRGBA) { 0x34/255., 0x65/255., 0xa4/255., 1.},
          (GdkRGBA) { 0x75/255., 0x50/255., 0x7b/255., 1.},
          (GdkRGBA) { 0x06/255., 0x98/255., 0x9a/255., 1.},
          (GdkRGBA) { 0xd3/255., 0xd7/255., 0xcf/255., 1.},
          (GdkRGBA) { 0x55/255., 0x57/255., 0x53/255., 1.},
          (GdkRGBA) { 0xef/255., 0x29/255., 0x29/255., 1.},
          (GdkRGBA) { 0x8a/255., 0xe2/255., 0x34/255., 1.},
          (GdkRGBA) { 0xfc/255., 0xe9/255., 0x4f/255., 1.},
          (GdkRGBA) { 0x72/255., 0x9f/255., 0xcf/255., 1.},
          (GdkRGBA) { 0xad/255., 0x7f/255., 0xa8/255., 1.},
          (GdkRGBA) { 0x34/255., 0xe2/255., 0xe2/255., 1.},
          (GdkRGBA) { 0xee/255., 0xee/255., 0xec/255., 1.},
        },
      },
    },
  },

  {
    .id = "dracula",
    .name = N_("Dracula"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x28/255., 0x2A/255., 0x36/255., 1.},
        .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .indexed = {
          (GdkRGBA) { 0xf1/255., 0xf2/255., 0xff/255., 1.},
          (GdkRGBA) { 0xb6/255., 0x00/255., 0x21/255., 1.},
          (GdkRGBA) { 0x00/255., 0x68/255., 0x00/255., 1.},
          (GdkRGBA) { 0x51/255., 0x5f/255., 0x00/255., 1.},
          (GdkRGBA) { 0x69/255., 0x46/255., 0xa3/255., 1.},
          (GdkRGBA) { 0xa4/255., 0x1d/255., 0x74/255., 1.},
          (GdkRGBA) { 0x00/255., 0x62/255., 0x74/255., 1.},
          (GdkRGBA) { 0xf8/255., 0xf8/255., 0xf2/255., 1.},
          (GdkRGBA) { 0x83/255., 0x93/255., 0xc7/255., 1.},
          (GdkRGBA) { 0xac/255., 0x20/255., 0x2f/255., 1.},
          (GdkRGBA) { 0x00/255., 0x68/255., 0x03/255., 1.},
          (GdkRGBA) { 0x58/255., 0x5e/255., 0x06/255., 1.},
          (GdkRGBA) { 0x6c/255., 0x49/255., 0x93/255., 1.},
          (GdkRGBA) { 0x96/255., 0x2f/255., 0x7c/255., 1.},
          (GdkRGBA) { 0x00/255., 0x64/255., 0x65/255., 1.},
          (GdkRGBA) { 0x59/255., 0x59/255., 0x59/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xf8/255., 0xf8/255., 0xf2/255., 1.},
        .background = (GdkRGBA) { 0x28/255., 0x2A/255., 0x36/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x21/255., 0x22/255., 0x2c/255., 1.},
          (GdkRGBA) { 0xff/255., 0x55/255., 0x55/255., 1.},
          (GdkRGBA) { 0x50/255., 0xfa/255., 0x7b/255., 1.},
          (GdkRGBA) { 0xf1/255., 0xfa/255., 0x8c/255., 1.},
          (GdkRGBA) { 0xbd/255., 0x93/255., 0xf9/255., 1.},
          (GdkRGBA) { 0xff/255., 0x79/255., 0xc6/255., 1.},
          (GdkRGBA) { 0x8b/255., 0xe9/255., 0xfd/255., 1.},
          (GdkRGBA) { 0xf8/255., 0xf8/255., 0xf2/255., 1.},
          (GdkRGBA) { 0x62/255., 0x72/255., 0xa4/255., 1.},
          (GdkRGBA) { 0xff/255., 0x6e/255., 0x6e/255., 1.},
          (GdkRGBA) { 0x69/255., 0xff/255., 0x94/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xa5/255., 1.},
          (GdkRGBA) { 0xd6/255., 0xac/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x92/255., 0xdf/255., 1.},
          (GdkRGBA) { 0xa4/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
    },
  },

  {
    .id = "nord",
    .name = N_("Nord"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x41/255., 0x48/255., 0x58/255., 1.},
        .background = (GdkRGBA) { 0xe5/255., 0xe9/255., 0xf0/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x3b/255., 0x42/255., 0x51/255., 1.},
          (GdkRGBA) { 0xbf/255., 0x60/255., 0x69/255., 1.},
          (GdkRGBA) { 0xa3/255., 0xbe/255., 0x8b/255., 1.},
          (GdkRGBA) { 0xea/255., 0xcb/255., 0x8a/255., 1.},
          (GdkRGBA) { 0x81/255., 0xa1/255., 0xc1/255., 1.},
          (GdkRGBA) { 0xb4/255., 0x8d/255., 0xac/255., 1.},
          (GdkRGBA) { 0x88/255., 0xc0/255., 0xd0/255., 1.},
          (GdkRGBA) { 0xd8/255., 0xde/255., 0xe9/255., 1.},
          (GdkRGBA) { 0x4c/255., 0x55/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xbf/255., 0x60/255., 0x69/255., 1.},
          (GdkRGBA) { 0xa3/255., 0xbe/255., 0x8b/255., 1.},
          (GdkRGBA) { 0xea/255., 0xcb/255., 0x8a/255., 1.},
          (GdkRGBA) { 0x81/255., 0xa1/255., 0xc1/255., 1.},
          (GdkRGBA) { 0xb4/255., 0x8d/255., 0xac/255., 1.},
          (GdkRGBA) { 0x8f/255., 0xbc/255., 0xbb/255., 1.},
          (GdkRGBA) { 0xec/255., 0xef/255., 0xf4/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xd8/255., 0xde/255., 0xe9/255., 1.},
        .background = (GdkRGBA) { 0x2e/255., 0x34/255., 0x40/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x3b/255., 0x42/255., 0x52/255., 1.},
          (GdkRGBA) { 0xbf/255., 0x61/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xa3/255., 0xbe/255., 0x8c/255., 1.},
          (GdkRGBA) { 0xeb/255., 0xcb/255., 0x8b/255., 1.},
          (GdkRGBA) { 0x81/255., 0xa1/255., 0xc1/255., 1.},
          (GdkRGBA) { 0xb4/255., 0x8e/255., 0xad/255., 1.},
          (GdkRGBA) { 0x88/255., 0xc0/255., 0xd0/255., 1.},
          (GdkRGBA) { 0xe5/255., 0xe9/255., 0xf0/255., 1.},
          (GdkRGBA) { 0x4c/255., 0x56/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xbf/255., 0x61/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xa3/255., 0xbe/255., 0x8c/255., 1.},
          (GdkRGBA) { 0xeb/255., 0xcb/255., 0x8b/255., 1.},
          (GdkRGBA) { 0x81/255., 0xa1/255., 0xc1/255., 1.},
          (GdkRGBA) { 0xb4/255., 0x8e/255., 0xad/255., 1.},
          (GdkRGBA) { 0x8f/255., 0xbc/255., 0xbb/255., 1.},
          (GdkRGBA) { 0xec/255., 0xef/255., 0xf4/255., 1.},
        },
      },
    },
  },

  {
    .id = "linux",
    .name = N_("Linux"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xaa/255., 0x00/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x55/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xaa/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x00/255., 0xaa/255., 1.},
          (GdkRGBA) { 0x00/255., 0xaa/255., 0xaa/255., 1.},
          (GdkRGBA) { 0xaa/255., 0xaa/255., 0xaa/255., 1.},
          (GdkRGBA) { 0x55/255., 0x55/255., 0x55/255., 1.},
          (GdkRGBA) { 0xff/255., 0x55/255., 0x55/255., 1.},
          (GdkRGBA) { 0x55/255., 0xff/255., 0x55/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x55/255., 1.},
          (GdkRGBA) { 0x55/255., 0x55/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x55/255., 0xff/255., 1.},
          (GdkRGBA) { 0x55/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .background = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xaa/255., 0x00/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x55/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xaa/255., 1.},
          (GdkRGBA) { 0xaa/255., 0x00/255., 0xaa/255., 1.},
          (GdkRGBA) { 0x00/255., 0xaa/255., 0xaa/255., 1.},
          (GdkRGBA) { 0xaa/255., 0xaa/255., 0xaa/255., 1.},
          (GdkRGBA) { 0x55/255., 0x55/255., 0x55/255., 1.},
          (GdkRGBA) { 0xff/255., 0x55/255., 0x55/255., 1.},
          (GdkRGBA) { 0x55/255., 0xff/255., 0x55/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x55/255., 1.},
          (GdkRGBA) { 0x55/255., 0x55/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x55/255., 0xff/255., 1.},
          (GdkRGBA) { 0x55/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
    },
  },

  {
    .id = "xterm",
    .name = N_("XTerm"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xee/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xe5/255., 0xe5/255., 0xe5/255., 1.},
          (GdkRGBA) { 0x7f/255., 0x7f/255., 0x7f/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0x5c/255., 0x5c/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .background = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xee/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xe5/255., 0xe5/255., 0xe5/255., 1.},
          (GdkRGBA) { 0x7f/255., 0x7f/255., 0x7f/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0x5c/255., 0x5c/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
    },
  },

  {
    .id = "rxvt",
    .name = N_("RXVT"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xfa/255., 0xeb/255., 0xd7/255., 1.},
          (GdkRGBA) { 0x40/255., 0x40/255., 0x40/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        .background = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
          (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
          (GdkRGBA) { 0xfa/255., 0xeb/255., 0xd7/255., 1.},
          (GdkRGBA) { 0x40/255., 0x40/255., 0x40/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
          (GdkRGBA) { 0x00/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
        },
      },
    },
  },

  {
    .id = "fishtank",
    .name = N_("Fishtank"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFE/255., 1.},
        .background = (GdkRGBA) { 0x23/255., 0x25/255., 0x37/255., 1.},
        .cursor = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFE/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x03/255., 0x07/255., 0x3C/255., 1.},
          (GdkRGBA) { 0xC6/255., 0x00/255., 0x4A/255., 1.},
          (GdkRGBA) { 0xAC/255., 0xF1/255., 0x57/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xCD/255., 0x5E/255., 1.},
          (GdkRGBA) { 0x52/255., 0x5F/255., 0xB8/255., 1.},
          (GdkRGBA) { 0x98/255., 0x6F/255., 0x82/255., 1.},
          (GdkRGBA) { 0x96/255., 0x87/255., 0x63/255., 1.},
          (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFC/255., 1.},
          (GdkRGBA) { 0x6C/255., 0x5B/255., 0x30/255., 1.},
          (GdkRGBA) { 0xDA/255., 0x4B/255., 0x8A/255., 1.},
          (GdkRGBA) { 0xDB/255., 0xFF/255., 0xA9/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xE6/255., 0xA9/255., 1.},
          (GdkRGBA) { 0xB2/255., 0xBE/255., 0xFA/255., 1.},
          (GdkRGBA) { 0xFD/255., 0xA5/255., 0xCD/255., 1.},
          (GdkRGBA) { 0xA5/255., 0xBD/255., 0x86/255., 1.},
          (GdkRGBA) { 0xF6/255., 0xFF/255., 0xEC/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFE/255., 1.},
        .background = (GdkRGBA) { 0x23/255., 0x25/255., 0x37/255., 1.},
        .cursor = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFE/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x03/255., 0x07/255., 0x3C/255., 1.},
          (GdkRGBA) { 0xC6/255., 0x00/255., 0x4A/255., 1.},
          (GdkRGBA) { 0xAC/255., 0xF1/255., 0x57/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xCD/255., 0x5E/255., 1.},
          (GdkRGBA) { 0x52/255., 0x5F/255., 0xB8/255., 1.},
          (GdkRGBA) { 0x98/255., 0x6F/255., 0x82/255., 1.},
          (GdkRGBA) { 0x96/255., 0x87/255., 0x63/255., 1.},
          (GdkRGBA) { 0xEC/255., 0xF0/255., 0xFC/255., 1.},
          (GdkRGBA) { 0x6C/255., 0x5B/255., 0x30/255., 1.},
          (GdkRGBA) { 0xDA/255., 0x4B/255., 0x8A/255., 1.},
          (GdkRGBA) { 0xDB/255., 0xFF/255., 0xA9/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xE6/255., 0xA9/255., 1.},
          (GdkRGBA) { 0xB2/255., 0xBE/255., 0xFA/255., 1.},
          (GdkRGBA) { 0xFD/255., 0xA5/255., 0xCD/255., 1.},
          (GdkRGBA) { 0xA5/255., 0xBD/255., 0x86/255., 1.},
          (GdkRGBA) { 0xF6/255., 0xFF/255., 0xEC/255., 1.},
        },
      },
    },
  },

  {
    .id = "spacedust",
    .name = N_("Spacedust"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xC1/255., 1.},
        .background = (GdkRGBA) { 0x0A/255., 0x1E/255., 0x24/255., 1.},
        .cursor = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xC1/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x6E/255., 0x53/255., 0x46/255., 1.},
          (GdkRGBA) { 0xE3/255., 0x5B/255., 0x00/255., 1.},
          (GdkRGBA) { 0x5C/255., 0xAB/255., 0x96/255., 1.},
          (GdkRGBA) { 0xE3/255., 0xCD/255., 0x7B/255., 1.},
          (GdkRGBA) { 0x0F/255., 0x54/255., 0x8B/255., 1.},
          (GdkRGBA) { 0xE3/255., 0x5B/255., 0x00/255., 1.},
          (GdkRGBA) { 0x06/255., 0xAF/255., 0xC7/255., 1.},
          (GdkRGBA) { 0xF0/255., 0xF1/255., 0xCE/255., 1.},
          (GdkRGBA) { 0x68/255., 0x4C/255., 0x31/255., 1.},
          (GdkRGBA) { 0xFF/255., 0x8A/255., 0x3A/255., 1.},
          (GdkRGBA) { 0xAE/255., 0xCA/255., 0xB8/255., 1.},
          (GdkRGBA) { 0xFF/255., 0xC8/255., 0x78/255., 1.},
          (GdkRGBA) { 0x67/255., 0xA0/255., 0xCE/255., 1.},
          (GdkRGBA) { 0xFF/255., 0x8A/255., 0x3A/255., 1.},
          (GdkRGBA) { 0x83/255., 0xA7/255., 0xB4/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xFF/255., 0xF1/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xC1/255., 1.},
        .background = (GdkRGBA) { 0x0A/255., 0x1E/255., 0x24/255., 1.},
        .cursor = (GdkRGBA) { 0xEC/255., 0xF0/255., 0xC1/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x6E/255., 0x53/255., 0x46/255., 1.},
          (GdkRGBA) { 0xE3/255., 0x5B/255., 0x00/255., 1.},
          (GdkRGBA) { 0x5C/255., 0xAB/255., 0x96/255., 1.},
          (GdkRGBA) { 0xE3/255., 0xCD/255., 0x7B/255., 1.},
          (GdkRGBA) { 0x0F/255., 0x54/255., 0x8B/255., 1.},
          (GdkRGBA) { 0xE3/255., 0x5B/255., 0x00/255., 1.},
          (GdkRGBA) { 0x06/255., 0xAF/255., 0xC7/255., 1.},
          (GdkRGBA) { 0xF0/255., 0xF1/255., 0xCE/255., 1.},
          (GdkRGBA) { 0x68/255., 0x4C/255., 0x31/255., 1.},
          (GdkRGBA) { 0xFF/255., 0x8A/255., 0x3A/255., 1.},
          (GdkRGBA) { 0xAE/255., 0xCA/255., 0xB8/255., 1.},
          (GdkRGBA) { 0xFF/255., 0xC8/255., 0x78/255., 1.},
          (GdkRGBA) { 0x67/255., 0xA0/255., 0xCE/255., 1.},
          (GdkRGBA) { 0xFF/255., 0x8A/255., 0x3A/255., 1.},
          (GdkRGBA) { 0x83/255., 0xA7/255., 0xB4/255., 1.},
          (GdkRGBA) { 0xFE/255., 0xFF/255., 0xF1/255., 1.},
        },
      },
    },
  },

  {
    .id = "catppuccin",
    .name = N_("Catppuccin"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x4c/255., 0x4f/255., 0x69/255., 1.},
        .background = (GdkRGBA) { 0xef/255., 0xf1/255., 0xf5/255., 1.},
        .cursor = (GdkRGBA) { 0x4c/255., 0x4f/255., 0x69/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x5c/255., 0x5f/255., 0x77/255., 1.},
          (GdkRGBA) { 0xd2/255., 0x0f/255., 0x39/255., 1.},
          (GdkRGBA) { 0x40/255., 0xa0/255., 0x2b/255., 1.},
          (GdkRGBA) { 0xdf/255., 0x8e/255., 0x1d/255., 1.},
          (GdkRGBA) { 0x1e/255., 0x66/255., 0xf5/255., 1.},
          (GdkRGBA) { 0xea/255., 0x76/255., 0xcb/255., 1.},
          (GdkRGBA) { 0x17/255., 0x92/255., 0x99/255., 1.},
          (GdkRGBA) { 0xac/255., 0xb0/255., 0xbe/255., 1.},
          (GdkRGBA) { 0x6c/255., 0x6f/255., 0x85/255., 1.},
          (GdkRGBA) { 0xd2/255., 0x0f/255., 0x39/255., 1.},
          (GdkRGBA) { 0x40/255., 0xa0/255., 0x2b/255., 1.},
          (GdkRGBA) { 0xdf/255., 0x8e/255., 0x1d/255., 1.},
          (GdkRGBA) { 0x1e/255., 0x66/255., 0xf5/255., 1.},
          (GdkRGBA) { 0xea/255., 0x76/255., 0xcb/255., 1.},
          (GdkRGBA) { 0x17/255., 0x92/255., 0x99/255., 1.},
          (GdkRGBA) { 0xbc/255., 0xc0/255., 0xcc/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xcd/255., 0xd6/255., 0xf4/255., 1.},
        .background = (GdkRGBA) { 0x1e/255., 0x1e/255., 0x2e/255., 1.},
        .cursor = (GdkRGBA) { 0xcd/255., 0xd6/255., 0xf4/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x45/255., 0x47/255., 0x5a/255., 1.},
          (GdkRGBA) { 0xf3/255., 0x8b/255., 0xa8/255., 1.},
          (GdkRGBA) { 0xa6/255., 0xe3/255., 0xa1/255., 1.},
          (GdkRGBA) { 0xf9/255., 0xe2/255., 0xaf/255., 1.},
          (GdkRGBA) { 0x89/255., 0xb4/255., 0xfa/255., 1.},
          (GdkRGBA) { 0xf5/255., 0xc2/255., 0xe7/255., 1.},
          (GdkRGBA) { 0x94/255., 0xe2/255., 0xd5/255., 1.},
          (GdkRGBA) { 0xba/255., 0xc2/255., 0xde/255., 1.},
          (GdkRGBA) { 0x58/255., 0x5b/255., 0x70/255., 1.},
          (GdkRGBA) { 0xf3/255., 0x8b/255., 0xa8/255., 1.},
          (GdkRGBA) { 0xa6/255., 0xe3/255., 0xa1/255., 1.},
          (GdkRGBA) { 0xf9/255., 0xe2/255., 0xaf/255., 1.},
          (GdkRGBA) { 0x89/255., 0xb4/255., 0xfa/255., 1.},
          (GdkRGBA) { 0xf5/255., 0xc2/255., 0xe7/255., 1.},
          (GdkRGBA) { 0x94/255., 0xe2/255., 0xd5/255., 1.},
          (GdkRGBA) { 0xa6/255., 0xad/255., 0xc8/255., 1.},
        },
      },
    },
  },

  {
    .id = "horizon",
    .name = N_("Horizon"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x1c/255., 0x1e/255., 0x26/255., 1.},
        .background = (GdkRGBA) { 0xfd/255., 0xf0/255., 0xed/255., 1.},
        .cursor = (GdkRGBA) { 0x1c/255., 0x1e/255., 0x26/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x16/255., 0x16/255., 0x1c/255., 1.},
          (GdkRGBA) { 0xda/255., 0x10/255., 0x3f/255., 1.},
          (GdkRGBA) { 0x1e/255., 0xb9/255., 0x80/255., 1.},
          (GdkRGBA) { 0xf6/255., 0x66/255., 0x1e/255., 1.},
          (GdkRGBA) { 0x26/255., 0xbb/255., 0xd9/255., 1.},
          (GdkRGBA) { 0xee/255., 0x64/255., 0xae/255., 1.},
          (GdkRGBA) { 0x1d/255., 0x89/255., 0x91/255., 1.},
          (GdkRGBA) { 0xfa/255., 0xda/255., 0xd1/255., 1.},
          (GdkRGBA) { 0x1a/255., 0x1c/255., 0x23/255., 1.},
          (GdkRGBA) { 0xf4/255., 0x3e/255., 0x5c/255., 1.},
          (GdkRGBA) { 0x07/255., 0xda/255., 0x8c/255., 1.},
          (GdkRGBA) { 0xf7/255., 0x7d/255., 0x26/255., 1.},
          (GdkRGBA) { 0x3f/255., 0xc6/255., 0xde/255., 1.},
          (GdkRGBA) { 0xf0/255., 0x75/255., 0xb7/255., 1.},
          (GdkRGBA) { 0x1e/255., 0xae/255., 0xae/255., 1.},
          (GdkRGBA) { 0xfd/255., 0xf0/255., 0xed/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xfd/255., 0xf0/255., 0xed/255., 1.},
        .background = (GdkRGBA) { 0x1c/255., 0x1e/255., 0x26/255., 1.},
        .cursor = (GdkRGBA) { 0xfd/255., 0xf0/255., 0xed/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x16/255., 0x16/255., 0x1c/255., 1.},
          (GdkRGBA) { 0xe9/255., 0x56/255., 0x78/255., 1.},
          (GdkRGBA) { 0x29/255., 0xd3/255., 0x98/255., 1.},
          (GdkRGBA) { 0xfa/255., 0xb7/255., 0x95/255., 1.},
          (GdkRGBA) { 0x26/255., 0xbb/255., 0xd9/255., 1.},
          (GdkRGBA) { 0xee/255., 0x64/255., 0xae/255., 1.},
          (GdkRGBA) { 0x59/255., 0xe3/255., 0xe3/255., 1.},
          (GdkRGBA) { 0xfa/255., 0xda/255., 0xd1/255., 1.},
          (GdkRGBA) { 0x23/255., 0x25/255., 0x30/255., 1.},
          (GdkRGBA) { 0xec/255., 0x6a/255., 0x88/255., 1.},
          (GdkRGBA) { 0x3f/255., 0xda/255., 0xa4/255., 1.},
          (GdkRGBA) { 0xfb/255., 0xc3/255., 0xa7/255., 1.},
          (GdkRGBA) { 0x3f/255., 0xc6/255., 0xde/255., 1.},
          (GdkRGBA) { 0xf0/255., 0x75/255., 0xb7/255., 1.},
          (GdkRGBA) { 0x6b/255., 0xe6/255., 0xe6/255., 1.},
          (GdkRGBA) { 0xfd/255., 0xf0/255., 0xed/255., 1.},
        },
      },
    },
  },

  {
    .id = "tokyo-night",
    .name = N_("Tokyo Night"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x56/255., 0x5a/255., 0x6e/255., 1.},
        .background = (GdkRGBA) { 0xd5/255., 0xd6/255., 0xdb/255., 1.},
        .cursor = (GdkRGBA) { 0x56/255., 0x5a/255., 0x6e/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x0f/255., 0x0f/255., 0x14/255., 1.},
          (GdkRGBA) { 0x8c/255., 0x43/255., 0x51/255., 1.},
          (GdkRGBA) { 0x48/255., 0x5e/255., 0x30/255., 1.},
          (GdkRGBA) { 0x8f/255., 0x5e/255., 0x15/255., 1.},
          (GdkRGBA) { 0x34/255., 0x54/255., 0x8a/255., 1.},
          (GdkRGBA) { 0x5a/255., 0x4a/255., 0x78/255., 1.},
          (GdkRGBA) { 0x0f/255., 0x4b/255., 0x6e/255., 1.},
          (GdkRGBA) { 0x34/255., 0x3b/255., 0x58/255., 1.},
          (GdkRGBA) { 0x96/255., 0x99/255., 0xa3/255., 1.},
          (GdkRGBA) { 0x8c/255., 0x43/255., 0x51/255., 1.},
          (GdkRGBA) { 0x48/255., 0x5e/255., 0x30/255., 1.},
          (GdkRGBA) { 0x8f/255., 0x5e/255., 0x15/255., 1.},
          (GdkRGBA) { 0x34/255., 0x54/255., 0x8a/255., 1.},
          (GdkRGBA) { 0x5a/255., 0x4a/255., 0x78/255., 1.},
          (GdkRGBA) { 0x0f/255., 0x4b/255., 0x6e/255., 1.},
          (GdkRGBA) { 0x34/255., 0x3b/255., 0x58/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xc0/255., 0xca/255., 0xf5/255., 1.},
        .background = (GdkRGBA) { 0x1a/255., 0x1b/255., 0x26/255., 1.},
        .cursor = (GdkRGBA) { 0xc0/255., 0xca/255., 0xf5/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x41/255., 0x48/255., 0x68/255., 1.},
          (GdkRGBA) { 0xf7/255., 0x76/255., 0x8e/255., 1.},
          (GdkRGBA) { 0x9e/255., 0xce/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xe0/255., 0xaf/255., 0x68/255., 1.},
          (GdkRGBA) { 0x7a/255., 0xa2/255., 0xf7/255., 1.},
          (GdkRGBA) { 0xbb/255., 0x9a/255., 0xf7/255., 1.},
          (GdkRGBA) { 0x7d/255., 0xcf/255., 0xff/255., 1.},
          (GdkRGBA) { 0xa9/255., 0xb1/255., 0xd6/255., 1.},
          (GdkRGBA) { 0x41/255., 0x48/255., 0x68/255., 1.},
          (GdkRGBA) { 0xf7/255., 0x76/255., 0x8e/255., 1.},
          (GdkRGBA) { 0x9e/255., 0xce/255., 0x6a/255., 1.},
          (GdkRGBA) { 0xe0/255., 0xaf/255., 0x68/255., 1.},
          (GdkRGBA) { 0x7a/255., 0xa2/255., 0xf7/255., 1.},
          (GdkRGBA) { 0xbb/255., 0x9a/255., 0xf7/255., 1.},
          (GdkRGBA) { 0x7d/255., 0xcf/255., 0xff/255., 1.},
          (GdkRGBA) { 0xc0/255., 0xca/255., 0xf5/255., 1.},
        },
      },
    },
  },

    {
    .id = "vscode",
    .name = N_("VS Code"),
    .faces = {
      {
        .foreground = (GdkRGBA) { 0x02/255., 0x02/255., 0x02/255., 1.},
        .background = (GdkRGBA) { 0xf9/255., 0xf9/255., 0xf9/255., 1.},
        .cursor = (GdkRGBA) { 0x02/255., 0x02/255., 0x02/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x02/255., 0x02/255., 0x02/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x32/255., 0x32/255., 1.},
          (GdkRGBA) { 0x00/255., 0xbc/255., 0x00/255., 1.},
          (GdkRGBA) { 0xa5/255., 0xa9/255., 0x00/255., 1.},
          (GdkRGBA) { 0x07/255., 0x52/255., 0xa8/255., 1.},
          (GdkRGBA) { 0xbc/255., 0x05/255., 0xbc/255., 1.},
          (GdkRGBA) { 0x05/255., 0x98/255., 0xbc/255., 1.},
          (GdkRGBA) { 0x34/255., 0x34/255., 0x34/255., 1.},
          (GdkRGBA) { 0x5e/255., 0x5e/255., 0x5e/255., 1.},
          (GdkRGBA) { 0xcd/255., 0x33/255., 0x33/255., 1.},
          (GdkRGBA) { 0x1b/255., 0xce/255., 0x1a/255., 1.},
          (GdkRGBA) { 0xad/255., 0xbb/255., 0x5b/255., 1.},
          (GdkRGBA) { 0x07/255., 0x52/255., 0xa8/255., 1.},
          (GdkRGBA) { 0xc4/255., 0x51/255., 0xce/255., 1.},
          (GdkRGBA) { 0x52/255., 0xa8/255., 0xc7/255., 1.},
          (GdkRGBA) { 0xa6/255., 0xa3/255., 0xa6/255., 1.},
        },
      },
      {
        .foreground = (GdkRGBA) { 0xcc/255., 0xcc/255., 0xcc/255., 1.},
        .background = (GdkRGBA) { 0x1e/255., 0x1e/255., 0x1e/255., 1.},
        .cursor = (GdkRGBA) { 0xcc/255., 0xcc/255., 0xcc/255., 1.},
        .indexed = {
          (GdkRGBA) { 0x6a/255., 0x78/255., 0x7a/255., 1.},
          (GdkRGBA) { 0xe9/255., 0x65/255., 0x3b/255., 1.},
          (GdkRGBA) { 0x39/255., 0xe9/255., 0xa8/255., 1.},
          (GdkRGBA) { 0xe5/255., 0xb6/255., 0x84/255., 1.},
          (GdkRGBA) { 0x44/255., 0xaa/255., 0xe6/255., 1.},
          (GdkRGBA) { 0xe1/255., 0x75/255., 0x99/255., 1.},
          (GdkRGBA) { 0x3d/255., 0xd5/255., 0xe7/255., 1.},
          (GdkRGBA) { 0xc3/255., 0xdd/255., 0xe1/255., 1.},
          (GdkRGBA) { 0x59/255., 0x84/255., 0x89/255., 1.},
          (GdkRGBA) { 0xe6/255., 0x50/255., 0x29/255., 1.},
          (GdkRGBA) { 0x00/255., 0xff/255., 0x9a/255., 1.},
          (GdkRGBA) { 0xe8/255., 0x94/255., 0x40/255., 1.},
          (GdkRGBA) { 0x00/255., 0x9a/255., 0xfb/255., 1.},
          (GdkRGBA) { 0xff/255., 0x57/255., 0x8f/255., 1.},
          (GdkRGBA) { 0x5f/255., 0xff/255., 0xff/255., 1.},
          (GdkRGBA) { 0xd9/255., 0xfb/255., 0xff/255., 1.},
        },
      },
    },
  },

    {
      .id = "monokai-soda",
      .name = N_("Monokai Soda"),
      .faces = {
        {
          .foreground = (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
          .background = (GdkRGBA) { 0x1a/255., 0x1a/255., 0x1a/255., 1.},
          .cursor = (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
          .indexed = {
            (GdkRGBA) { 0x1a/255., 0x1a/255., 0x1a/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x98/255., 0xe0/255., 0x24/255., 1.},
            (GdkRGBA) { 0xfa/255., 0x84/255., 0x19/255., 1.},
            (GdkRGBA) { 0x9d/255., 0x65/255., 0xff/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x58/255., 0xd1/255., 0xeb/255., 1.},
            (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
            (GdkRGBA) { 0x62/255., 0x5e/255., 0x4c/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x98/255., 0xe0/255., 0x24/255., 1.},
            (GdkRGBA) { 0xe0/255., 0xd5/255., 0x61/255., 1.},
            (GdkRGBA) { 0x9d/255., 0x65/255., 0xff/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x58/255., 0xd1/255., 0xeb/255., 1.},
            (GdkRGBA) { 0xf6/255., 0xf6/255., 0xef/255., 1.},
          },
        },
        {
          .foreground = (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
          .background = (GdkRGBA) { 0x1a/255., 0x1a/255., 0x1a/255., 1.},
          .cursor = (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
          .indexed = {
            (GdkRGBA) { 0x1a/255., 0x1a/255., 0x1a/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x98/255., 0xe0/255., 0x24/255., 1.},
            (GdkRGBA) { 0xfa/255., 0x84/255., 0x19/255., 1.},
            (GdkRGBA) { 0x9d/255., 0x65/255., 0xff/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x58/255., 0xd1/255., 0xeb/255., 1.},
            (GdkRGBA) { 0xc4/255., 0xc5/255., 0xb5/255., 1.},
            (GdkRGBA) { 0x62/255., 0x5e/255., 0x4c/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x98/255., 0xe0/255., 0x24/255., 1.},
            (GdkRGBA) { 0xe0/255., 0xd5/255., 0x61/255., 1.},
            (GdkRGBA) { 0x9d/255., 0x65/255., 0xff/255., 1.},
            (GdkRGBA) { 0xf4/255., 0x00/255., 0x5f/255., 1.},
            (GdkRGBA) { 0x58/255., 0xd1/255., 0xeb/255., 1.},
            (GdkRGBA) { 0xf6/255., 0xf6/255., 0xef/255., 1.},
          },
        },
      },
    },

    {
      .id = "xterm",
      .name = N_("XTerm"),
      .faces = {
        {
          .cursor = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          .foreground = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          .background = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
          .indexed = {
            (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
            (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0x00/255., 0xee/255., 1.},
            (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
            (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
            (GdkRGBA) { 0xe5/255., 0xe5/255., 0xe5/255., 1.},
            (GdkRGBA) { 0x7f/255., 0x7f/255., 0x7f/255., 1.},
            (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
            (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
            (GdkRGBA) { 0x5c/255., 0x5c/255., 0xff/255., 1.},
            (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
            (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
            (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
          },
        },
        {
          .cursor = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
          .foreground = (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
          .background = (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
          .indexed = {
            (GdkRGBA) { 0x00/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0xcd/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0xcd/255., 0x00/255., 1.},
            (GdkRGBA) { 0xcd/255., 0xcd/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0x00/255., 0xee/255., 1.},
            (GdkRGBA) { 0xcd/255., 0x00/255., 0xcd/255., 1.},
            (GdkRGBA) { 0x00/255., 0xcd/255., 0xcd/255., 1.},
            (GdkRGBA) { 0xe5/255., 0xe5/255., 0xe5/255., 1.},
            (GdkRGBA) { 0x7f/255., 0x7f/255., 0x7f/255., 1.},
            (GdkRGBA) { 0xff/255., 0x00/255., 0x00/255., 1.},
            (GdkRGBA) { 0x00/255., 0xff/255., 0x00/255., 1.},
            (GdkRGBA) { 0xff/255., 0xff/255., 0x00/255., 1.},
            (GdkRGBA) { 0x5c/255., 0x5c/255., 0xff/255., 1.},
            (GdkRGBA) { 0xff/255., 0x00/255., 0xff/255., 1.},
            (GdkRGBA) { 0x00/255., 0xff/255., 0xff/255., 1.},
            (GdkRGBA) { 0xff/255., 0xff/255., 0xff/255., 1.},
          },
        },
      },
    },

};

G_END_DECLS
